@@ -25,9 +25,6 @@ namespace Aquamarine {
         virtual ~CDRMBufferAttachment() {
             ;
         }
-        virtual eAttachmentType type() {
-            return AQ_ATTACHMENT_DRM_BUFFER;
-        }
 
         Hyprutils::Memory::CSharedPointer<CDRMFB> fb;
     };
@@ -40,9 +37,6 @@ namespace Aquamarine {
         virtual ~CDRMBufferUnimportable() {
             ;
         }
-        virtual eAttachmentType type() {
-            return AQ_ATTACHMENT_DRM_KMS_UNIMPORTABLE;
-        }
     };
 
     class CDRMLease {
@@ -59,7 +53,7 @@ namespace Aquamarine {
         bool                                                     active = true;
 
         struct {
-            Hyprutils::Signal::CSignal destroy;
+            Hyprutils::Signal::CSignalT<> destroy;
         } events;
 
       private:
@@ -375,6 +369,7 @@ namespace Aquamarine {
         virtual Hyprutils::Memory::CSharedPointer<IAllocator>              preferredAllocator();
         virtual std::vector<SDRMFormat>                                    getRenderableFormats();
         virtual std::vector<Hyprutils::Memory::CSharedPointer<IAllocator>> getAllocators();
+        virtual Hyprutils::Memory::CWeakPointer<IBackendImplementation>    getPrimary();
 
         Hyprutils::Memory::CWeakPointer<CDRMBackend>                       self;
 
